using static System.Console;
using System.Drawing;
using System.Windows.Forms;

class Game {
  public int size;
  public bool[,] a;
  
  public Game(int size) {
    this.size = size;
    a = new bool[size, size];
    
    calculate();
  }
  
  // Return true if we can move along (dx, dy) to any square
  // whose value is false.
  bool canWin(bool[,] a, int x, int y, int dx, int dy) {
    int size = a.GetLength(0);
    x += dx;
    y += dy;
    
    while (x < size && y < size) {
      if (!a[x, y])
        return true;  // we can win
      x += dx;
      y += dy;
    }
    
    return false;  // we cannot win  
  }
  
  void calculate() {
    for (int y = size - 1; y >= 0 ; --y)
      for (int x = size - 1; x >= 0 ; --x)
        a[x, y] = canWin(a, x, y, 1, 0) ||
                  canWin(a, x, y, 1, 1) ||
                  canWin(a, x, y, 0, 1);
  }
}

class View : Form {
  Game game = new Game(16);
  
  Pen pen = new Pen(Color.White, 0);
  
  public View() {
    ClientSize = new Size(100 * (game.size + 1), 100 * (game.size + 1));
    Paint += onPaint;
  }
  
  void onPaint(object sender, PaintEventArgs e) {
    Graphics g = e.Graphics;
    g.TranslateTransform(50, 50);
    g.ScaleTransform(50, 50);
    
    for (int x = 0 ; x < game.size ; ++x)
      for (int y = 0 ; y < game.size ; ++y)
        g.FillRectangle(
          game.a[x, y] ? Brushes.Red : Brushes.Blue,
          x, y, 1, 1);
          
    for (int i = 1 ; i < game.size ; ++i) {
      g.DrawLine(pen, i, 0, i, game.size);
      g.DrawLine(pen, 0, i, game.size, i);
    }
    
  }
  
  static void Main() {
    Application.Run(new View());
  }
}
